@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use CPAN::Meta;
 use Carp;
@@ -147,6 +147,14 @@ option test => (
         . ' @mentions of other people so they do not get a flood of email while you test.',
 );
 
+option debug_ua => (
+    is      => 'ro',
+    isa     => t('Bool'),
+    lazy    => 1,
+    default => 0,
+    doc     => 'Use LWP::ConsoleLogger to debug the interactions with RT',
+);
+
 has _default_dist_name => (
     is      => 'ro',
     isa     => t('Str'),
@@ -390,6 +398,22 @@ sub _build_rt_client {
     my $self = shift;
 
     my $rt = RT::Client::REST->new( server => 'https://rt.cpan.org/' );
+
+    if ( $self->debug_ua ) {
+        require LWP::ConsoleLogger;
+        my $logger = LWP::ConsoleLogger->new(
+            dump_params => 1,
+        );
+        $rt->_ua->add_handler(
+            'response_done',
+            sub { $logger->response_callback(@_) }
+        );
+        $rt->_ua->add_handler(
+            'request_send',
+            sub { $logger->request_callback(@_) }
+        );
+    }
+
     $rt->login(
         username => $self->pause_id,
         password => $self->pause_password,
@@ -519,15 +543,20 @@ sub _extract_ticket_data {
         my $trans = shift;
 
         my $user = $cache{ $trans->creator } ||= do {
-            my $u = RT::Client::REST::User->new(
-                id => $trans->creator,
-                rt => $trans->rt,
-            );
-            $u->retrieve;
-            $u;
+            try {
+                my $u = RT::Client::REST::User->new(
+                    id => $trans->creator,
+                    rt => $trans->rt,
+                );
+                $u->retrieve;
+                $u;
+            };
         };
 
-        my $email = lc( $user->email_address // 'unknown' );
+        my $email;
+        $email = lc $user->email_address if $user;
+        $email //= lc $trans->creator;
+
         return sprintf(
             'From %s on %s:',
             $self->_maybe_tag_email($email),
@@ -747,7 +776,7 @@ RTx::ToGitHub - Convert rt.cpan.org tickets to GitHub issues
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
